import React, {Component} from 'react'
import PropTypes from 'prop-types'
import { Form, Row, Col, Input, Radio, Tooltip, Icon } from 'antd'

import './index.scss'

const { TextArea } = Input

class SettingForm extends Component {
  static propTpyes = {
    menu: PropTypes.object,    // 卡片行信息
    inputSubmit: PropTypes.func  // 回车事件
  }

  state = {
    property: this.props.menu.property || 'menu'
  }

  UNSAFE_componentWillMount () {
    
  }

  handleConfirm = () => {
    // 表单提交时检查输入值是否正确
    return new Promise((resolve, reject) => {
      this.props.form.validateFieldsAndScroll((err, values) => {
        if (!err) {
          resolve(values)
        } else {
          reject(err)
        }
      })
    })
  }

  handleSubmit = (e) => {
    e.preventDefault()

    if (this.props.inputSubmit) {
      this.props.inputSubmit()
    }
  }

  changeProperty = (e) => {
    let val = e.target.value

    this.setState({property: val})
  }

  render() {
    const { menu } = this.props
    const { getFieldDecorator } = this.props.form
    const { property } = this.state

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 }
      }
    }

    return (
      <Form {...formItemLayout}>
        <Row gutter={24}>
          <Col span={24}>
            <Form.Item label="菜单名称">
              {getFieldDecorator('name', {
                initialValue: menu.name,
                rules: [
                  {
                    required: true,
                    message: '请输入菜单名称!'
                  }
                ]
              })(<Input placeholder={''} autoComplete="off" onPressEnter={this.handleSubmit} />)}
            </Form.Item>
          </Col>
          <Col span={24}>
            <Form.Item label="属性">
              {getFieldDecorator('property', {
                initialValue: menu.property || 'menu'
              })(
                <Radio.Group onChange={this.changeProperty}>
                  <Radio value="menu">菜单</Radio>
                  <Radio value="link">链接</Radio>
                  <Radio value="classify">分类</Radio>
                </Radio.Group>
              )}
            </Form.Item>
          </Col>
          {property === 'link' ? <Col span={24}>
            <Form.Item label={
              <Tooltip placement="topLeft" title="链接至当前系统的菜单时，可以使用 $ + 菜单ID，例如：$dsdffowejdsfi。">
                <Icon type="question-circle" style={{color: '#c49f47', marginRight: '3px'}}/>
                链接地址
              </Tooltip>
            }>
              {getFieldDecorator('link', {
                initialValue: menu.link || '',
                rules: [
                  {
                    required: true,
                    message: '请输入链接地址!'
                  }
                ]
              })(<TextArea rows={2} />)}
            </Form.Item>
          </Col> : null}
          {property === 'menu' ? <Col span={24}>
            <Form.Item label={
              <Tooltip placement="topLeft" title="复制其他菜单时，请填写对应的菜单ID。">
                <Icon type="question-circle" style={{color: '#c49f47', marginRight: '3px'}}/>
                复制菜单
              </Tooltip>
            }>
              {getFieldDecorator('copyMenu', {
                initialValue: menu.copyMenu || ''
              })(
                <Input placeholder={''} autoComplete="off" onPressEnter={this.handleSubmit} />
              )}
            </Form.Item>
          </Col> : null}
        </Row>
      </Form>
    )
  }
}

export default Form.create()(SettingForm)